Peripheral access API for APOLLO3 microcontrollers (generated using svd2rust v0.19.0 ( ))
You can find an overview of the generated API here.
API features to be included in the next
svd2rust release can be generated by cloning the svd2rust repository, checking out the above commit, and running cargo doc --open.
Modules
- adc
- Analog Digital Converter Control
- apbdma
- APB DMA Register Interfaces
- bleif
- BLE Interface
- cachectrl
- Flash Cache Controller
- clkgen
- Clock Generator
- ctimer
- Counter/Timer
- generic
- Common register and bit access and modify traits
- gpio
- General Purpose IO
- iom0
- IO Peripheral Master
- ioslave
- I2C/SPI Slave
- mcuctrl
- MCU Miscellaneous Control Logic
- mspi
- Multibit SPI Master
- pdm
- PDM Audio
- pwrctrl
- PWR Controller Register Bank
- rstgen
- MCU Reset Generator
- rtc
- Real Time Clock
- scard
- Serial ISO7816
- security
- Security Interfaces
- uart0
- Serial UART
- vcomp
- Voltage Comparator
- wdt
- Watchdog Timer
Structs
- ADC
- Analog Digital Converter Control
- APBDMA
- APB DMA Register Interfaces
- BLEIF
- BLE Interface
- CACHECTRL
- Flash Cache Controller
- CBP
- Cache and branch predictor maintenance operations
- CLKGEN
- Clock Generator
- CPUID
- CPUID
- CTIMER
- Counter/Timer
- Core
Peripherals - Core peripherals
- DCB
- Debug Control Block
- DWT
- Data Watchpoint and Trace unit
- FPB
- Flash Patch and Breakpoint unit
- FPU
- Floating Point Unit
- GPIO
- General Purpose IO
- IOM0
- IO Peripheral Master
- IOM1
- IO Peripheral Master
- IOM2
- IO Peripheral Master
- IOM3
- IO Peripheral Master
- IOM4
- IO Peripheral Master
- IOM5
- IO Peripheral Master
- IOSLAVE
- I2C/SPI Slave
- ITM
- Instrumentation Trace Macrocell
- MCUCTRL
- MCU Miscellaneous Control Logic
- MPU
- Memory Protection Unit
- MSPI
- Multibit SPI Master
- NVIC
- Nested Vector Interrupt Controller
- PDM
- PDM Audio
- PWRCTRL
- PWR Controller Register Bank
- Peripherals
- All the peripherals
- RSTGEN
- MCU Reset Generator
- RTC
- Real Time Clock
- SCARD
- Serial ISO7816
- SCB
- System Control Block
- SECURITY
- Security Interfaces
- SYST
- SysTick: System Timer
- TPIU
- Trace Port Interface Unit
- UART0
- Serial UART
- UART1
- Serial UART
- VCOMP
- Voltage Comparator
- WDT
- Watchdog Timer
Enums
- Interrupt
- Enumeration of all the interrupts.
Constants
- NVIC_
PRIO_ BITS - Number available in the NVIC for configuring priority