pub struct R(/* private fields */);Expand description
Register CTRL reader
Implementations
Sourceimpl R
impl R
Sourcepub fn flash1_slm_enable(&self) -> FLASH1_SLM_ENABLE_R
pub fn flash1_slm_enable(&self) -> FLASH1_SLM_ENABLE_R
Bit 10 - Enable Flash Sleep Mode. Write to 1 to put flash 1 into sleep mode. NOTE: there is a 5us latency after waking flash until the first access will be returned.
Sourcepub fn flash1_slm_disable(&self) -> FLASH1_SLM_DISABLE_R
pub fn flash1_slm_disable(&self) -> FLASH1_SLM_DISABLE_R
Bit 9 - Disable Flash Sleep Mode. Write 1 to wake flash1 from sleep mode (reading the array will also automatically wake it).
Sourcepub fn flash1_slm_status(&self) -> FLASH1_SLM_STATUS_R
pub fn flash1_slm_status(&self) -> FLASH1_SLM_STATUS_R
Bit 8 - Flash Sleep Mode Status. 1 indicates that flash1 is in sleep mode, 0 indicates flash1 is in normal mode.
Sourcepub fn flash0_slm_enable(&self) -> FLASH0_SLM_ENABLE_R
pub fn flash0_slm_enable(&self) -> FLASH0_SLM_ENABLE_R
Bit 6 - Enable Flash Sleep Mode. Write to 1 to put flash 0 into sleep mode. NOTE: there is a 5us latency after waking flash until the first access will be returned.
Sourcepub fn flash0_slm_disable(&self) -> FLASH0_SLM_DISABLE_R
pub fn flash0_slm_disable(&self) -> FLASH0_SLM_DISABLE_R
Bit 5 - Disable Flash Sleep Mode. Write 1 to wake flash0 from sleep mode (reading the array will also automatically wake it).
Sourcepub fn flash0_slm_status(&self) -> FLASH0_SLM_STATUS_R
pub fn flash0_slm_status(&self) -> FLASH0_SLM_STATUS_R
Bit 4 - Flash Sleep Mode Status. 1 indicates that flash0 is in sleep mode, 0 indicates flash0 is in normal mode.
Sourcepub fn cache_ready(&self) -> CACHE_READY_R
pub fn cache_ready(&self) -> CACHE_READY_R
Bit 2 - Cache Ready Status (enabled and not processing an invalidate operation)
Sourcepub fn reset_stat(&self) -> RESET_STAT_R
pub fn reset_stat(&self) -> RESET_STAT_R
Bit 1 - Reset Cache Statistics. When written to a 1, the cache monitor counters will be cleared. The monitor counters can be reset only when the CACHECFG.ENABLE_MONITOR bit is set.
Sourcepub fn invalidate(&self) -> INVALIDATE_R
pub fn invalidate(&self) -> INVALIDATE_R
Bit 0 - Writing a 1 to this bitfield invalidates the flash cache contents.